==> jc-1.4.0.tar.gz: javax/crypto/spec/PBEKeySpec.h <==
// public class javax.crypto.spec.PBEKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bfebafcf1c1935d javax_crypto_spec_PBEKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_PBEKeySpec_H_
#define _JC_javax_crypto_spec_PBEKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_PBEKeySpec$sub_refs	_jc_javax_crypto_spec_PBEKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs	_jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$refs	_jc_javax_crypto_spec_PBEKeySpec$refs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$nonrefs	_jc_javax_crypto_spec_PBEKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$object	_jc_javax_crypto_spec_PBEKeySpec$object;

typedef const struct _jc_javax_crypto_spec_PBEKeySpec$vmethods	_jc_javax_crypto_spec_PBEKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_PBEKeySpec$vtable	_jc_javax_crypto_spec_PBEKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_PBEKeySpec$vtype	_jc_javax_crypto_spec_PBEKeySpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_PBEKeySpec$method$_init$5ce098f98647e5ca(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *, struct _jc_char_array *);
extern void _jc_javax_crypto_spec_PBEKeySpec$method$_init$c602098f3d593c12(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *, struct _jc_char_array *, struct _jc_byte_array *, jint);
extern void _jc_javax_crypto_spec_PBEKeySpec$method$_init$228250c1e1f5e06f(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *, struct _jc_char_array *, struct _jc_byte_array *, jint, jint);

// Virtual methods
extern void _jc_javax_crypto_spec_PBEKeySpec$method$clearPassword$5500d515bfb0eaa8(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
extern jint _jc_javax_crypto_spec_PBEKeySpec$method$getIterationCount$c84099ed1055b2b4(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
extern jint _jc_javax_crypto_spec_PBEKeySpec$method$getKeyLength$c3c6279e9ddfb174(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
extern _jc_char_array *_jc_javax_crypto_spec_PBEKeySpec$method$getPassword$6adf0c63e283126f(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
extern _jc_byte_array *_jc_javax_crypto_spec_PBEKeySpec$method$getSalt$d47caba1a97e2fb5(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$clearPassword$5500d515bfb0eaa8;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getIterationCount$c84099ed1055b2b4;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getKeyLength$c3c6279e9ddfb174;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getPassword$6adf0c63e283126f;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getSalt$d47caba1a97e2fb5;

// Virtual methods structure
struct _jc_javax_crypto_spec_PBEKeySpec$vmethods {
	void	(*clearPassword$5500d515bfb0eaa8)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
	jint	(*getIterationCount$c84099ed1055b2b4)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
	jint	(*getKeyLength$c3c6279e9ddfb174)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
	_jc_char_array	*(*getPassword$6adf0c63e283126f)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
	_jc_byte_array	*(*getSalt$d47caba1a97e2fb5)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_PBEKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_PBEKeySpec$vmethods	javax_crypto_spec_PBEKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_PBEKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_PBEKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEKeySpec$sub_refs {
	_jc_char_array	*password;
	_jc_byte_array	*salt;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_PBEKeySpec$refs {
    _jc_javax_crypto_spec_PBEKeySpec$sub_refs	javax_crypto_spec_PBEKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs {
	jint	iterationCount;
	jint	keyLength;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_PBEKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs	javax_crypto_spec_PBEKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_PBEKeySpec$object {
	_jc_javax_crypto_spec_PBEKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_PBEKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_PBEKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_PBEKeySpec$vtype _jc_javax_crypto_spec_PBEKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_PBEKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_PBEKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_PBEKeySpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/PBEKeySpec.h <==
// public class javax.crypto.spec.PBEKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bfebafcf1c1935d javax_crypto_spec_PBEKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_PBEKeySpec_H_
#define _JC_javax_crypto_spec_PBEKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_PBEKeySpec$sub_refs	_jc_javax_crypto_spec_PBEKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs	_jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$refs	_jc_javax_crypto_spec_PBEKeySpec$refs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$nonrefs	_jc_javax_crypto_spec_PBEKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_PBEKeySpec$object	_jc_javax_crypto_spec_PBEKeySpec$object;

typedef const struct _jc_javax_crypto_spec_PBEKeySpec$vmethods	_jc_javax_crypto_spec_PBEKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_PBEKeySpec$vtable	_jc_javax_crypto_spec_PBEKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_PBEKeySpec$vtype	_jc_javax_crypto_spec_PBEKeySpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_PBEKeySpec$method$_init$5ce098f98647e5ca(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *, struct _jc_char_array *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_PBEKeySpec$method$_init$c602098f3d593c12(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *, struct _jc_char_array *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_PBEKeySpec$method$_init$228250c1e1f5e06f(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *, struct _jc_char_array *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_crypto_spec_PBEKeySpec$method$clearPassword$5500d515bfb0eaa8(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_PBEKeySpec$method$getIterationCount$c84099ed1055b2b4(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_PBEKeySpec$method$getKeyLength$c3c6279e9ddfb174(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
extern _jc_char_array *_jc_javax_crypto_spec_PBEKeySpec$method$getPassword$6adf0c63e283126f(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_javax_crypto_spec_PBEKeySpec$method$getSalt$d47caba1a97e2fb5(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$clearPassword$5500d515bfb0eaa8;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getIterationCount$c84099ed1055b2b4;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getKeyLength$c3c6279e9ddfb174;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getPassword$6adf0c63e283126f;
extern _jc_method _jc_javax_crypto_spec_PBEKeySpec$method_info$getSalt$d47caba1a97e2fb5;

// Virtual methods structure
struct _jc_javax_crypto_spec_PBEKeySpec$vmethods {
	void	(*clearPassword$5500d515bfb0eaa8)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
	jint	(*getIterationCount$c84099ed1055b2b4)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
	jint	(*getKeyLength$c3c6279e9ddfb174)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
	_jc_char_array	*(*getPassword$6adf0c63e283126f)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getSalt$d47caba1a97e2fb5)(_jc_env *, struct _jc_javax_crypto_spec_PBEKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_PBEKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_PBEKeySpec$vmethods	javax_crypto_spec_PBEKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_PBEKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_PBEKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEKeySpec$sub_refs {
	_jc_char_array	*password;
	_jc_byte_array	*salt;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_PBEKeySpec$refs {
    _jc_javax_crypto_spec_PBEKeySpec$sub_refs	javax_crypto_spec_PBEKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs {
	jint	iterationCount;
	jint	keyLength;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_PBEKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_PBEKeySpec$sub_nonrefs	javax_crypto_spec_PBEKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_PBEKeySpec$object {
	_jc_javax_crypto_spec_PBEKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_PBEKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_PBEKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_PBEKeySpec$vtype _jc_javax_crypto_spec_PBEKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_PBEKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_PBEKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_PBEKeySpec_H_ */
